@@ -53,30 +53,25 @@ class ValidationActions(object):
         # Get validation data:
         vlog = ValidationLogs(log_path)
         data = v_utils.get_validations_data(validation, self.validation_path)
+        if not data:
+            msg = "Validation {} not found in the path: {}".format(
+                validation,
+                self.validation_path)
+            raise RuntimeError(msg)
         logfiles = vlog.get_all_logfiles_content()
         format = vlog.get_validations_stats(logfiles)
         data.update(format)
         return data
 
-    def run_validations(self, playbook=[], inventory='localhost',
+    def run_validations(self, validation_name=None, inventory='localhost',
                         group=None, extra_vars=None, validations_dir=None,
-                        validation_name=None, extra_env_vars=None,
-                        ansible_cfg=None, quiet=True, workdir=None,
-                        limit_hosts=None, run_async=False,
+                        extra_env_vars=None, ansible_cfg=None, quiet=True,
+                        workdir=None, limit_hosts=None, run_async=False,
                         base_dir=constants.DEFAULT_VALIDATIONS_BASEDIR):
         self.log = logging.getLogger(__name__ + ".run_validations")
         playbooks = []
         validations_dir = (validations_dir if validations_dir
                            else self.validation_path)
-
-        if playbook:
-            if isinstance(playbook, list):
-                playbooks = playbook
-            elif isinstance(playbook, str):
-                playbooks = [playbook]
-            else:
-                raise TypeError("Playbooks should be a List or a Str")
-
         if group:
             self.log.debug('Getting the validations list by group')
             try:
@@ -158,9 +153,10 @@ class ValidationActions(object):
                 f.write(params)
         return params
 
-    def show_history(self, validation_id=None, extension='json'):
+    def show_history(self, validation_id=None, extension='json',
+                     log_path=constants.VALIDATIONS_LOG_BASEDIR):
         """Return validations history"""
-        vlogs = ValidationLogs(self.validation_path)
+        vlogs = ValidationLogs(log_path)
         logs = (vlogs.get_logfile_by_validation(validation_id)
                 if validation_id else vlogs.get_all_logfiles(extension))
 
@@ -168,11 +164,35 @@ class ValidationActions(object):
         column_name = ('UUID', 'Validations',
                        'Status', 'Execution at',
                        'Duration')
-
         for log in logs:
             vlog = ValidationLog(logfile=log)
             if vlog.is_valid_format():
-                values.append((vlog.get_uuid, vlog.validation_id,
-                               vlog.get_status, vlog.get_start_time,
-                               vlog.get_duration))
+                for play in vlog.get_plays:
+                    values.append((play['id'], play['validation_id'],
+                                   vlog.get_status,
+                                   play['duration'].get('start'),
+                                   play['duration'].get('time_elapsed')))
+        return (column_name, values)
+
+    def get_status(self, validation_id=None, uuid=None, status='FAILED',
+                   log_path=constants.VALIDATIONS_LOG_BASEDIR):
+        """Return validations execution details by status"""
+        vlogs = ValidationLogs(log_path)
+        if validation_id:
+            logs = vlogs.get_logfile_by_validation(validation_id)
+        elif uuid:
+            logs = vlogs.get_logfile_by_uuid(uuid)
+        else:
+            raise RuntimeError("You need to provide a validation_id or a uuid")
+
+        values = []
+        column_name = ['name', 'host', 'status', 'task_data']
+        for log in logs:
+            vlog = ValidationLog(logfile=log)
+            if vlog.is_valid_format():
+                for task in vlog.get_tasks_data:
+                    if task['status'] == status:
+                        for host in task['hosts']:
+                            values.append((task['name'], host, task['status'],
+                                           task['hosts'][host]))
         return (column_name, values)
